@@ -1,5 +1,6 @@
 from functools import wraps, partial
 from inspect import getfullargspec
+from typing import Callable, Union, Any
 
 import fn
 
@@ -14,14 +15,19 @@ class F(fn.F):
 
     @property
     def name(self):
-        f = self.f.func if self._is_partial else self.f
-        return f.__name__
+        from amino.anon import AnonCallable
+        f = (
+            self.f.func
+            if isinstance(self.f.func, AnonCallable) else
+            self.f.func.__name__
+        ) if self._is_partial else self.f.__name__
+        return str(f)
 
     @property
     def _is_partial(self):
         return isinstance(self.f, partial)
 
-    def __repr__(self):
+    def __str__(self):
         from amino.anon import format_funcall
         rep = (format_funcall(self.name, self.f.args, self.f.keywords)
                if self._is_partial
@@ -51,13 +57,31 @@ class Identity:
     def __call__(self, a):
         return a
 
-    def __repr__(self):
-        return 'a => a'
+    def __str__(self):
+        return '(a => a)'
 
 I = Identity()
 
 
+class Val:
+
+    def __init__(self, value) -> None:
+        self.value = value
+
+    def __call__(self):
+        return self.value
+
+    def __str__(self):
+        return '{}({})'.format(self.__class__.__name__, self.value)
+
+
 def flip(a, b):
     return b, a
 
-__all__ = ('curried', 'F', 'I', 'flip')
+CallByName = Union[Any, Callable[[], Any]]
+
+
+def call_by_name(b: CallByName):
+    return b() if callable(b) else b  # type: ignore
+
+__all__ = ('curried', 'F', 'I', 'flip', 'call_by_name', 'Val')
