@@ -55,9 +55,8 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
 
     @staticmethod
     def random_string(num: int=10):
-        from amino.anon import _
         chars = string.ascii_letters + string.digits
-        return ''.join(random.choice(chars) for _ in range(num))
+        return ''.join(random.choice(chars) for i in range(num))
 
     @staticmethod
     def gen(num: int, f: Callable[[], A]):
@@ -136,9 +135,15 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
         return self.last.product(self.init)
 
     @property
-    def distinct(self):
-        seen = set()
-        return List.wrap(x for x in self if x not in seen and not seen.add(x))
+    def distinct(self) -> 'List[A]':
+        return self.distinct_by(I)
+
+    def distinct_by(self, f: Callable[[A], bool]) -> 'List[A]':
+        seen = set()  # type: set
+        def pred(a):
+            v = f(a)
+            return v in seen or seen.add(v)
+        return List.wrap(x for x in self if not pred(x))
 
     def add(self, other: typing.List[A]) -> 'List[A]':
         return List.wrap(typing.List.__add__(self, other))
@@ -181,12 +186,23 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     def join_lines(self):
         return self.mk_string('\n')
 
+    @property
+    def join_comma(self):
+        return self.mk_string(', ')
+
+    @property
+    def join_tokens(self):
+        return self.mk_string(' ')
+
     def cons(self, item):
         return List.wrap(cons(item, self))
 
     def cat(self, item):
         return self + List(item)
 
+    def cat_m(self, item: maybe.Maybe):
+        return item / self.cat | self
+
     @property
     def transpose(self):
         return List.wrap(map(List.wrap, zip(*self)))
@@ -202,7 +218,10 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
         return self.filter_not(els.contains)
 
     def __repr__(self):
-        return 'List({})'.format(', '.join(map(safe_string, self)))
+        return 'List({})'.format(', '.join(map(repr, self)))
+
+    def __str__(self):
+        return '[{}]'.format(', '.join(map(safe_string, self)))
 
     def __hash__(self):
         return hash(tuple(self))
