@@ -1,12 +1,11 @@
 import os
 import re
 import logging
+import operator
 from typing import Callable
 import sys
 from pathlib import Path
 
-from fn import F, _
-
 from amino.lazy import lazy
 
 import amino
@@ -28,7 +27,7 @@ class Logger(logging.Logger):
             self._log(DDEBUG, message, args, **kws)
 
     def caught_exception(self, when, exc, *a, **kw):
-        headline = 'caught exception during {}'.format(when)
+        headline = 'caught exception while {}:'.format(when)
         self.exception(headline, exc_info=(type(exc), exc, exc.__traceback__))
 
 
@@ -84,7 +83,7 @@ def amino_file_logging(level: int=None, logfile=default_logfile,
         _file_logging_initialized = True
 
 
-class Logging(object):
+class Logging:
 
     @property
     def log(self) -> Logger:
@@ -94,12 +93,17 @@ class Logging(object):
     def _log(self) -> Logger:
         return amino_logger(self.__class__.__name__)
 
+    def _p(self, a):
+        v = self.log.verbose
+        v(a)
+        return a
+
 
 def sub_loggers(loggers, root):
-    from amino import Map
-    children = loggers.keyfilter(F(re.match, '{}\.[^.]+$'.format(root)))
-    sub = (children.k / F(sub_loggers, loggers))\
-        .fold_left(Map())(_ ** _)
+    from amino import Map, _, L
+    children = loggers.keyfilter(L(re.match)('{}\.[^.]+$'.format(root), _))
+    sub = (children.k / L(sub_loggers)(loggers, _))\
+        .fold_left(Map())(operator.pow)
     return Map({loggers[root]: sub})
 
 
@@ -116,7 +120,8 @@ def indent(strings, level, width=1):
 
 
 def format_logger_tree(tree, fmt_logger, level=0):
-    sub_f = F(format_logger_tree, fmt_logger=fmt_logger, level=level + 1)
+    from amino import _, L
+    sub_f = L(format_logger_tree)(_, fmt_logger, level=level + 1)
     formatted = tree.bimap(fmt_logger, sub_f)
     return '\n'.join(indent(formatted.map2('{}\n{}'.format), level))
 
